function [done,results,indxf_0]=auto_stage0(y,x,indcte,r00,rmod,alpha,f0_sig,eta,z,f_bup,results)
 
// PURPOSE: eliminates variables whose joint significance is
// lower than f0_sig under the condition that no diagnostic
// fails
// ------------------------------------------------------------
// INPUT:
// * y = vector of the endogenous variable
// * x = matrix of the exogenous variables
// * indcte = index of the constant variable (= nvar+1 if there
//   is no constant in the r00 model)
// * r00 = results of the estimation (by ols or ols2) of the
// model Y = X*b+U
// * rmod = a tlist defined by def_results
// * alpha = the simplification significance level
// * f0_sig = for the pre-test significance level
// * eta = a vector equal to the significance levels for the
//   specification tests
// * z = matrix of the compulsory variables (the ones that must
//   be in the regression whatever significance they have
// ------------------------------------------------------------
// OUPTUT:
// * done = %t if all variables are significant, %f otherwise
// * r0 = results structure of the final model (the one without
//  the eliminated variables) as provided by ols2
// * indxf: indexes in x of the remaining exogenous variables
// ------------------------------------------------------------
// NOTES:
// * used by automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2005
// http://dubois.ensae.net/grocer.html
 
// sort pvalues by decreasing order and save in indpvalue
// their indexes
 
 
nz=size(z,2)
[gpvalue,indpvalue]=gsort(r00('pvalue')(nz+1:$),'g','d')
 
if gpvalue(1) < alpha then
// the lowest tstat is nevertheless significant: the initial model is the final one!
   r0=r00
   done=%t
   results('final model')=r1_00
   results('ending reason')='initial model=final model'
   indxf_0=[]
else
   nvar=r00('nvar')
   done=%f
   r=r00
   count=1
   t1=0
   fp=1
   p=ones(size(eta,1),1)
 
   while (fp >= f0_sig) & (t1 < 1) & and (p > eta)...
      & ( count < (nvar-nz)) then
      r0=r
   // eliminate the next less significant variable from the list
   // of exogenous variables
      count=count+1
      indxf_0=gsort(indpvalue(count:(nvar-nz)),'g','i')
      xd=x(:,indxf_0)
   // estimate the new model with minimal output and use of a
   // preexisting tlist structure to save time
      r=grocer_estim1(y,[z xd],rmod)
      r('sigu')=max(r('sigu'),r00('sigu')+sqrt(%eps))
      r('sige')=r('sigu')/(r('nobs')-r('nvar'))
      [val,p]=test_func(r)
      [fstat,fp]=waldf0(r,r00)
      t1=abs(r('tstat')(find(indxf_0==indpvalue(count))))
   end
 
   if (count == nvar-nz) & (fp >= f0_sig) & (t1 < 1) & and (p > eta) then
      // there is only one variable left in the model
      fp=waldf0([],r00)
      if fp >= f0_sig then
         r0=[]
         done=%t
         results('final model')=[]
         results('ending reason')='stage 0 model is empty'
         return
       end
   end
 
   if or(p <= eta) | (fp < f0_sig) then
   // the search has stopped because the last model was not
   // valid so you must not count it
      indxf_0=gsort(indpvalue(count-1:nvar-nz),'g','i')
      xd=x(:,indxf_0)
      if count==2 then
         r0=grocer_estim1(y,[z xd],rmod)
      end
   else
 
   // the last model is valid, but it cannot be simplified
   // further because there are no more (insignificant)
   // variable to drop
       r0=r
       [val,p]=test_func(r)
   end
 
   // update and complete the tlist structure corresponding to
   // the last regression
   nobs=r0('nobs')
   nvar0=r0('nvar')
   resid=r0('resid')
   r0('ser')=sqrt(r0('sigu')/(nobs-nvar0))
   ediff = resid(2:nobs)-resid(1:nobs-1)
   dw = ediff'*ediff/r0('sigu')
   // durbin-watson
   condindex=bkwols(xd)
   prescte=or(indxf_0 == indcte)
 
   r0('dw')=dw
   r0('condindex')=condindex
   r0('prescte')=prescte
   r0('namex')=[r00('namex')(1:nz) ; r00('namex')(nz+indxf_0)]
   if prescte & nvar0 ~=1 then
   // there is a constant and at least another exogenous
   //  variable: R and Rbar make sense
      r0 =add_r2(r0,r0('sigu'),r0('ym'),nobs,nvar0)
   else
      r0('prescte')=%f
   end
   r0('spec_test')=[val p]
   results(1)($+1)='top-down model'
   results($+1)=r0
   results(1)($+1)='stage 0 model'
   results(1)($+1)='selected stage 0 model'
 
   // now undertake the bottom-up step
   ind_sig=find(gpvalue < alpha)
   if isempty(ind_sig) then
      results('stage 0 model')=r0
      results('selected stage 0 model')='top down model'
 
   else
      results(1)($+1)='bottom-up model'
      indxf=gsort(indpvalue(ind_sig(1):(nvar-nz)),'g','i')
      if indxf == indxf_0 then
         results('bottom-up model')=r0
         results('stage 0 model')=r0
         results('selected stage 0 model')='bottom-up model'
 
      else
         xd=x(:,indxf)
         r=grocer_estim1(y,[z xd],rmod)
         r('sige')=r('sigu')/(r('nobs')-r('nvar'))
         [val,p]=test_func(r)
 
         if and(p > eta) then
         // the bottom-up model passes the specification tests:
         // it is therefore valid
 
            [fstat,fp]=waldf0(r,r0)
 
            // update and complete the tlist structure corresponding to
            // the last regression
            nvar=r('nvar')
            resid=r('resid')
            r('ser')=sqrt(r('sigu')/(nobs-nvar))
            ediff = resid(2:nobs)-resid(1:nobs-1)
            dw = ediff'*ediff/r('sigu')
         // durbin-watson
            condindex=bkwols(xd)
            prescte=or(indxf == indcte)
 
            r('dw')=dw
            r('condindex')=condindex
            r('prescte')=prescte
            r('namex')=[r00('namex')(1:nz) ; r00('namex')(nz+indxf)]
            if prescte & nvar ~=1 then
            // there is a constant and at least another exogenous
            //  variable: R and Rbar make sense
               r=add_r2(r,r('sigu'),r('ym'),nobs,nvar)
            else
               r('prescte')=%f
            end
 
            r('spec_test')=[val p]
            r(1)($+1)='indxf'
            r('indxf')=indxf
 
            results($+1)=r
 
            if fp > f_bup then
               results('stage 0 model')=r
               results('selected stage 0 model')='bottom-up model'
               indxf_0=indxf
            else
               results('stage 0 model')=r0
               results('selected stage 0 model')='top down model'
            end
 
         else
            results('stage 0 model')=r0
            results('selected stage 0 model')='top down model'
         end
      end
   end
end
 
endfunction
 
