function [f,f_pvalue,nvar2,r2]=hetero_sq0_a(r,np)
 
// PURPOSE: provides the value of the Xi hetero test
// and its significance level; special version for automatic
// that takes into account the possibility that there are more
// regressors than observations; in that case the test is not
// performed but is supposed to pass
// ------------------------------------------------------------
// INPUT:
// * r = results tlist from a first stage estimation
// * np = unused argument put for compatibility with other
// testing functions
// ------------------------------------------------------------
// OUPTUT:
// * f = value of the Xi hetero F test
// * f_pvalue = its p-value
// ------------------------------------------------------------
// NOTES:
// used by the following functions:
// automatic()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2004
 
 
 
nvar=r('nvar')
nobs=r('nobs')
u2=r('resid').^2
xd=ones(nobs,1)
x=r('x')
for i=1:nvar
   xd=[xd x(:,i)]
   nx=size(xd,2)
   [u,d,v] = svd(xd,0);
   lamda = diag(d(1:nx,1:nx));
   if (lamda($)/lamda(1))^2 < 1E-6 then
      xd(:,$)=[]
   end
 
   xd=[xd x(:,i).^2]
   nx=size(xd,2)
   [u,d,v] = svd(xd,0);
   lamda = diag(d(1:nx,1:nx));
 
   if (lamda($)/lamda(1))^2 < 1E-6 then
      xd(:,$)=[]
   end
end
 
if nobs-nvar-size(xd,2) > 0 & or(xd ~= 1) then
   [f,f_pvalue,nvar2,r2]=bpagan0(u2,xd,nvar)
else
// either there are too many regressors in the auxiliary regression
// or there is only the constant term
   f=0
   f_pvalue=1
end
 
endfunction
