function [resid]=detrend(y,p)
 
// PURPOSE: detrend a matrix y using regression
//          of y against a polynomial time trend of order p
// ------------------------------------------------------------
// INPUT:
// * y = input matrix (or vector) of time-series (nobs x nvar)
// * p = trend degree
//   . p = 0, subtracts mean
//   . p = 1, constant plus trend model
//   . p > 1, higher order polynomial model
//   . p = -1, returns y
// ------------------------------------------------------------
// OUTPUT:
// resid = residuals from the detrending regression
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
// adapted to scilab from:
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jlesage@spatial-econometrics.com
 
 
 
[nargout,nargin] = argn(0)
// error checking on input arguments
if nargin~=2 then
  error('Wrong # of arguments to detrend');
end
 
if p==(-1) then
   resid = y;
   return
end
 
[nobs,junk] = size(y);
u = ones(nobs,1);
 
if p>0 then
  timep = zeros(nobs,p);
  t = 1:nobs;
  tp = t'/nobs;
  m = 1;
  while m<=p then
    timep(:,m) = tp.^m;
    m = m+1;
  end
  xmat = [u,timep];
else
  xmat = u;
end
 
bet = ols0(y,xmat);
resid = y-xmat*bet;
 
endfunction
 
