function xma = mak(x,k)
 
// PURPOSE: Calculates a 2 sided k-period centered moving average
//---------------------------------------------------------
// INPUT:
// * x   = original time series
// * k   = size of the moving average filter
// -------------------------------------------------------------
// OUTPUT:
// * xma = filtered timeseries
// -------------------------------------------------------------
// Adapted and arranged by E. Michaux (2005)
// from Julien Matheron, Banque de France, centre de recherche.
 
 
 
if (k/2 == int(k/2)) then
   w = [0;ones(k,1)]+[ones(k,1);0] ;
   incr = k;
else
   w = ones(k,1) ;
   incr = k-1;
end
s = w/sum(w) ;
 
xpad = [ x(1,1)*ones(floor(k/2),1) ; x ; x(size(x,1),1)*ones(floor(k/2),1) ] ;
xma = zeros(size(x,1),1) ;
 
for i =1:size(x,1)
   xma(i) = s'*xpad(i:i+incr,1);
end
 
endfunction
 
