function [out]=matdiv(x,y)
 
// PURPOSE: perform matrix quotient even if matrices
// are not of the same dimension, but are row or
// column compatible
// ------------------------------------------------------------
// INPUT:
// x,y = two matrices (not of the same dimension
// but that are row or column compatible)
// ------------------------------------------------------------
// OUTPUT:
// out = x./y where x and y are row or column compatible
// ------------------------------------------------------------
// NOTES: used by lad()
// ------------------------------------------------------------
 
// translated by Eric Dubois from:
// James P. LeSage, Dept of Economics
// University of Toledo
// 2801 W. Bancroft St,
// Toledo, OH 43606
// jpl@jpl.econ.utoledo.edu
 
 
 
[rx,cx] = size(x);
[ry,cy] = size(y);
rmax = max([rx,ry]);
cmax = max([cx,cy]);
out = ones(rmax,cmax);
if (cx==cy)&(rx==ry) then
  out = x ./ y;
elseif (cx==cy)&(min([rx,ry])==1) then
  for i = 1:cx
    out(:,i) = x(:,i) ./ y(:,i);
  end
elseif (rx==ry)&(min([cx,cy])==1) then
  for i = 1:rx
    out(i,:) = x(i,:) ./ y(i,:);
  end
else
  error('matdiv: non-conformable in row or column dimension');
end
 
endfunction
 
