function [dh,pn]=doornhans0(res,np)
 
// PURPOSE : "omnibus" normality test
// ------------------------------------------------------------
// references : J. Doornik and H. Hansen (1994) : "A practical
// test for univariate and multivariate normality", Discussion
// Paper, Nuffield College
// ------------------------------------------------------------
// INPUT:
// * res = a result tlist
// * np= unused argument put for compatibility with other
//   testing functions
// ------------------------------------------------------------
// OUTPUT:
// * dh = the value of the test
// * pn = its p-value
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
 
 
 
 
resid=res('resid')
mresid=mean(resid)
n = res('nobs')
k = res('nvar')
m2 = sum( (resid-mresid).^2 )/n
m3 = sum( (resid-mresid).^3 )/n
m4 = sum( (resid-mresid).^4 )/n
rb1 = m3/m2^1.5
b2 = m4/m2^2
 
bet=3*(n^2+27*n-70)*(n+1)*(n+3)/(n-2)/(n+5)/(n+7)/(n+9)
om2=-1+sqrt(2*(bet-1))
delta=log(sqrt(om2))^(-0.5)
y=rb1*sqrt((om2-1)*(n+1)*(n+3)/12/(n-2))
s=delta*log(y+sqrt(y^2+1))
 
delta=(n-3)*(n+1)*(n^2+15*n-4)
a=(n-2)*(n+5)*(n+7)*(n^2+27*n-70)/6/delta
c=(n-7)*(n+5)*(n+7)*(n^2+2*n-5)/6/delta
k= (n+5)*(n+7)*(n^3+37*n^2+11*n-313)/12/delta
alpha=a+rb1^2*c
khi=(b2-1-rb1^2)*2*k
k=((khi/2/alpha)^(1/3)-1+1/9/alpha)*sqrt(9*alpha)
 
dh = s^2 + k^2 ;
pn = 1 - cdfchi("PQ",dh,2)
 
endfunction
