function [C]=aggreg1(N,s,opt)
 
// PURPOSE: Generate a temporal aggregation matrix
// ------------------------------------------------------------
// INPUT:
// * N = number of low frequency data
// * s = freq. conversion
// * opt = type of temporal aggregation:
//   - opt = -1 ---> sum (flow)
//   - opt = 0 ---> average (index)
//   - opt = k ---> k-th element (k>=1 and k<=s)
// ------------------------------------------------------------
// OUTPUT:
// C = (N x sN) temporal aggregation matrix
// ------------------------------------------------------------
// Copyright: Eric Dubois 2005
// translated and adpated to Scilab from a Matlab program
// written by:
// Enrique M. Quilis
// Instituto Nacional de Estadistica
// Paseo de la Castellana, 183
// 28046 - Madrid (SPAIN)
 
 
 
select opt
case -1 then
   c = ones(1,s);
case 0 then
   c = ones(1,s)/s;
else
   c = zeros(1,s);
   c(opt) = 1
end
 
// ------------------------------------------------------------
// Temporal aggregation matrix
 
C = eye(N,N) .*. c;
 
endfunction
