function res=johansen_normalize(res,vari)
 
// PURPOSE: normalize the eigen vector and error correction
// term from a johansen estimation
// ------------------------------------------------------------
// INPUT:
// * res = a johansen results tlist
// * vari = a vector indicating the variables used for each
//  normalization
// ------------------------------------------------------------
// OUTPUT:
// res = the original tlist except for the 'evec' (eigen
// vectors) and 'alpha' (error correction) fields changed
// by the normalization
// ------------------------------------------------------------
// Copyright: Eric Dubois 2009
 
 
 
alpha=res('alpha')
evec=res('evec')
ny=res('nvar')
 
for i=1:size(vari,'*')
   v=evec(vari(i),i)
   evec(:,i)=evec(:,i)/v
   alpha(i,:)=alpha(i,:)*v
end
 
res('alpha')=alpha
res('evec')=evec
 
res_1=res(1)
if or(res_1 == 'nb of cointegration relations') then
   prtjohvec(res,res('nb of cointegration relations'))
else
   prtjohvec(res,res('nvar'))
end
 
endfunction
