function param = MSVAR_SetInit(y_mat,x_mat,z_mat,M,var_opt,M_V,typmod,apriori,init_beta_id,init_beta_co,init_prob,init_var);
 
// PURPOSE: initialize a  choosen MS model following a typmod
// specification
// ------------------------------------------------------------
// INPUT:
// * ymat= (T x K) matrix of endogenous variables
// * xmat= (T x n_x) matrix of non switching exogenous variables
// * zmat= (T x n_z) matrix of switching exogenous variables
// * M = a scalar equal to the # of states
// * var_opt = a scalar equal to the type of the variance of
//   residuals
// * M_V = a scalar indicating whether the variance switches or
//   not
// * typmod = a scalar equal to the type of the model
// * apriori = a (T x 1) vector equal to an a priori datation
//   of the states
// ------------------------------------------------------------
// OUTPUT:
// * param = a (np x 1) vector of parameters
// ------------------------------------------------------------
// Adapted to Scilab by Eric Dubois
// from Gauss library MSVarlib 2.0
// Copyright (C) 2004 by Benoit BELLONE.
// http://bellone.ensae.net
// All rights reserved
 
 
 
[beta_id_out,beta_co_out,var_cova,var_covb]= MSVAR_InitOls(y_mat,x_mat,z_mat,M,typmod,apriori,M_V,init_beta_id,init_beta_co,init_var);	
 
//======================Beta, Delta and Covariance Matrices automatic Initialization ======================
select M_V
case 1 then
   var_cov=var_cova
case M then
   var_cov=var_covb
end
 
if (typmod==1) |(typmod==2) | (typmod==5) then ;
   vv= [vecr(beta_id_out);vecr(var_cov)];
 
else
   vv= [vecr(beta_id_out);vecr(var_cov);vecr(beta_co_out)];
 
end;
 
//======================Sets the transition probability matrix  =========================
 
PR_TR=zeros(M-1,M);
p=0;
z=p;
q=p;
 
// ============= Symetric automatic intialization with no limitation of number of states, see the related Pdf file for // explanations ============
 
ksi=0.9;
 
if typeof(init_prob) == 'boolean' then
   if M==2 then
// if  a two state Model
      p=log(ksi/(1-ksi));
      PR_TR=[p ; p];
 
   else
   // if a three or more state model
      delta=(1-ksi)/(M-1);
      chi=1+(M-2)*(delta/ksi);
 
      p=log(ksi/(1-ksi*chi));
   // gives pii=f(thetaii), invariant probabilities : exp(p)/(1+exp(p)+(M-2)*exp(q))=ksi */
 
      q=p+log(delta/ksi);
   // pij=f(thetaij), for j=1..M-1 : exp(q)/(1+exp(p)+(M-2)*exp(q))=delta */
 
      z=log(delta/(1-(M-1)*delta));
   // zgives piMf(thetaiM), for i=1..M-1 : exp(z)/(1+(M-1)*exp(z))=delta */
 
      A=(p-q)*eye(M-1,M-1)+q*ones(M-1,M-1); 			
      // First block of thetaij, for j=1..M-1*/
      B=z*ones(M-1,1); 																		// Second block of thetaij, for j=M */
      PR_TR=[A B];
 
   end;
 
else
   init_prob=init_prob(M-1,M)
   sum_prob=sum(init_prob,'r') .*. ones(M-1,1)
   PR_TR=log(init_prob .* (1+sum_prob ./ (1-sum_prob)))
 
end
 
//=========== Final result param, vector of parameters: first come the transition probabilities, then beta and sigma =========*/
 
param=[vecr(PR_TR);vv];
endfunction
