function []=pltseries(varargin)
 
// PURPOSE: plots series... (scilab function plot2d, but with
// some scilab parameters fixed and new possibilities, such as
// ts)
// ------------------------------------------------------------
// INPUT:
// * (optional) varargin:
//   - a time series
//   - a real (nxp) vector
//   - a string equal to the name of a time series or a (nxp)
//     real vector between quotes
//   - a matrix or a list of such elements
//   - 'title=x' if the user wants to give its own title
//     (default: the name of the ts if it has been given
//     between quotes, the string 'ts' if not)
//   - 'bounds=[''b1'' ; ''b2'' ;...; ''bn'']' if the user
//     wants to give its own grocer_bounds
//     (default: the whole series)
//   - 'yaxex=xx' if the user wants to put the x axis at value
//      xx (default: y minimum value)
//   - 'yaxis=xx' where xx is a (1xp) matrix of 1 and 2, if the
//      user wants 2 axes, respectively at the left and the
//      right of the graph; the j the series is represented on
//      the left axis if xx(j)==1 and on the right one if
//      xx(j)==2
//      (default: only a left axis)
//   - 'bars = xx' with xx integer row vector of size p
//     representing the nature of the representation of the
//     series (1=bars; anything else = curves)
//   - 'x0(1)=xx' with xx integer representing the x location
//     of the first y axis (default: put at x=1)
//   - 'x0(2)=xx' with xx integer representing the x location
//     of the second y axis (default: put at x=nobs)
//   - 'x=xx' where xx is the (1xnobs) string vector to put
//     on the x axis
//   - styleg =  integer row vector of size p representing the style of each piece of the legend
//   - color = integer row vector of size p representing the line color of each series
//   - style = integer row vector of size p representing the line style of each series
//   - leg = title of the legend
//   - 'window=x' if the user wants to specify the # x where
//     the graph is plotted
//     (default: the window 1)
//   - 'x0=xx' with xx interger representing the y location
//     of the x axis (default: put at y=1)
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the graphic window
// ------------------------------------------------------------
// Copyright: Eric Dubois 2004
 
 
 
nargin=length(varargin)
// set defaults
wind=1
grocer_y=[]
grocer_leg=%t
y0=[]
grocer_l=list()
 
for i=length(varargin):-1:1
   if typeof(varargin(i)) == 'string' then
      str2=part(varargin(i),1:2)
      str3=part(varargin(i),1:3)
      str4=part(varargin(i),1:4)
      str5=part(varargin(i),1:5)
      str6=part(varargin(i),1:6)
      l=length(varargin(i))
      endc=part(varargin(i),strindex(varargin(i),'=')+1:l)
      select str6
      case 'bounds' then
         grocer_boundsvar=evstr(endc)
         varargin(i)=null()
      case 'window' then
         wind=evstr(endc)
         varargin(i)=null()
      else
         select str5
         case 'title' then
            tit=endc
            varargin(i)=null()
         case 'yaxex' then
            y0=evstr(endc)
            varargin(i)=null()
         case 'yaxis' then
            yax=varargin(i)
            varargin(i)=null()
         else
            if str3 == 'leg' then
               strleg=endc
               varargin(i)=null()
            elseif str2 == 'x=' then
               xscale0=endc
               varargin(i)=null()
            elseif str5 == 'noleg' then
               grocer_leg=%f
               varargin(i)=null()
            elseif str5 ~= 'color' & str5 ~= 'style' & str4 ~= 'bars' & str2 ~= 'x0' then
               grocer_l($+1)=varargin(i)
               varargin(i)=null()
            end
         end
      end
   elseif typeof(varargin(i)) == 'constant' then
      grocer_l($+1)=varargin(i)
      varargin(i)=null()
   end
end
 
if exists('grocer_boundsvar','local') then
// ! warning: where they are written, these lines of code
// allow one to draw ts which are defined only as a vector
// very useful (cf. garch.sci), but a little bit dangerous !
   if size(grocer_boundsvar,2) ~= 1  then
      if size(grocer_boundsvar,1) == 1 then
         grocer_boundsvar=grocer_boundsvar'
      else
         error('your grocer_bounds are not a vector of strings')
      end
   end
   for i=1:size(grocer_boundsvar,1)/2
      [d1,fq]=date2num_fq(grocer_boundsvar(i*2-1))
      xscale0=num2date([d1:d1+diff_date(grocer_boundsvar(2*i),...
           grocer_boundsvar(2*i-1))]',date2fq(grocer_boundsvar(i*2-1)))'
   end
else
   grocer_boundsvar=[]
end
 
grocer_lb=list()
for i=1:length(grocer_l)
   grocer_lb($+1)=grocer_l(length(grocer_l)+1-i)
end
 
[grocer_y,grocer_namexos,grocer_boundsvarb,grocer_prests]=explox(grocer_lb,'series',grocer_boundsvar,'wna')
nobs=size(grocer_y,1)
 
// if the user has not given any tittle, then generate it
if ~exists('tit','local') then
   tit=''
end
// if the user has not given any legend, then generate it
if ~exists('strleg','local') & grocer_leg then
   if exists('yax','local') then
      execstr(yax)
      yaxis=string(yaxis)
      yaxis= strsubst(yaxis,'1','lhs')
      yaxis= strsubst(yaxis,'2','rhs')
      strleg=joinstr(grocer_namexos,' (',yaxis,')',';')
   else
      strleg='['+joinstr(grocer_namexos,';')+']'
   end
end
 
if ~exists('xscale0','local') then
   if grocer_prests then
      dn=date2num_m(grocer_boundsvarb)
      dscale=[]
      for i=1:size(dn,1)/2
         dscale=[dscale dn(2*i-1):dn(2*i)]
      end
      xscale0=num2date(dscale,date2fq(grocer_boundsvarb(1)))
   else
      xscale0=string([1:nobs])
   end
end
 
if ~exists('yax','local') then
   yax='yaxis=['+joinstr(string(ones(1,size(grocer_y,2))),',')+']'
end
 
if grocer_leg then
   pltseries0(grocer_y,y0,tit,xscale0,wind,'leg='+strleg,yax,varargin(:))
else
   pltseries0(grocer_y,y0,tit,xscale0,wind,yax,varargin(:))
end
endfunction
