function []=pltseries0(y,y0,title,xscale0,wind,varargin)
 
// PURPOSE: plots series... (scilab function plot2d, but with
// some scilab parameters fixed and new possibilities, such as
// ts, the mixing of bars and curves, the possibility to have
// 2 different axes,...)
// ------------------------------------------------------------
// INPUT:
// * y = the (nxp) values real matrix of the graphed series
// * y0 = the value where to draw the x axis or [] if the user
//   wants the axis to be put a the y minimum value
// * title = title of the graph
// * xscale0 = a (nx1) string vector representing the x scale
// * wind = the number of the window where to draw the graph
//   (-1 if the user wants to draw it on the currently opened
//    window)
// * varargin = optional arguments:
//   - 'styleg =xx' with xx integer row vector of size p
//     representing the location of the legend
//     (default: 5, that is the legend is placed interactively
//      with the mouse, see legends in the help menu)
//   - 'style = xx' with xx integer row vector of size p
//     representing the line style of each series
//   - 'color = xx' with xx integer row vector of size p
//      representing the line color of each series
//   - 'leg = tit' with tit = title of the legend
//   - 'yaxis = xx' with xx integer row vector of size p
//     representing the axis for each series (1=left; 2=right)
//   - 'bars = xx' with xx integer row vector of size p
//     representing the nature of the representation of the
//     series (1=bars; anything else = curves)
//   - 'x0(1)=xx' with xx integer representing the x location
//     of the first y axis (default: put at x=1)
//   - 'x0(2)=xx' with xx integer representing the x location
//     of the second y axis (default: put at x=nobs)
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the graphic window
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2005
 
// load the parameters that determines the fonts
 
global GROCERDIR;
 
load(GROCERDIR+'/data/param_g.dat')
 
set("old_style","on")
nargin=length(varargin)
[nobs,ny]=size(y)
// set default values
secondaxis=%f
sty=[1:ny]
styleg=5
bars=zeros(ny,1)
x0=[1 nobs]
x0given=%f
ydeb=[]
y_1=[1:ny]
y_2=[]
just_scale=%f
 
for i=1:nargin
   l=length(varargin(i))
   endc=part(varargin(i),strindex(varargin(i),'=')+1:l)
   if part(varargin(i),1:6) == 'styleg' then
      styleg=evstr(endc)
   elseif part(varargin(i),1:5) == 'color' then
      pltcol=vec2row(evstr(endc))
   elseif part(varargin(i),1:5) == 'style' then
      sty=evstr(endc)
   elseif part(varargin(i),1:3) == 'leg' then
      legend0=str2vec(varargin(i))
   elseif part(varargin(i),1:4) == 'bars' then
      bars=evstr(endc)
   elseif part(varargin(i),1:5) == 'yaxis' then
      execstr(varargin(i))
      if or(yaxis==2) then
         y_1=find(yaxis == 1)
         y_2=find(yaxis ~= 1)
         secondaxis=%t
      end
   elseif part(varargin(i),1:2) == 'x0' then
      execstr(varargin(i))
   end
end
 
min_x0=int(min(x0))
max_x0=int(max(x0))
 
if wind ~= -1 then
   xset("window",wind)
// clean the screen:
   xbasc(wind)
end
 
nbars=sum(bars==1)
if nbars ~= 0 then
   y0=0
   if ~x0given then
      min_x0=0
   end
end
 
yext1=[]
yext2=[]
if min_x0 <=0 then
   yext1=%nan*ones(-min_x0+1,1)
end
if max_x0 > nobs then
   yext2=%nan*ones(max_x0-nobs+1,1)
end
 
font_title=min(maxcar,maxcar-floor(lengthtitle=max(length(title))/thresh))
 
xset("font size",font_title)
xtitle(title)
 
xset("font size",min(font_axis,3))
 
// choose default colors
if ~exists('pltcol','local') then
   pltcol=[1 2 5 14 24 3:4 6:13]
   pltcol=pltcol(1:ny)
end
 
// if there are bars in the graph, then the x axis is drawn at y=0
 
width_bars=nbars+bool2s(nbars>2)
xdeb=max(floor(width_bars/2),1)
xending=width_bars-xdeb+(nbars==0)
 
bari=0
ny1=size(y_1,2)
for i=1:ny1
   i1=y_1(i)
   xset("line style",sty(i1))
   yi=y(:,i1)
   if bars(i1) == 1 then
      bari=bari+1
      xset("thickness",1)
      yext=[yext1 ; yi .*. [0*[1:bari-1]' ; 1 ; 0*[bari+1:nbars+bool2s(nbars>2)]' ] yext2]
      [listx,listy]=dealyna(yext)
      for j=1:length(listx)
         plot2d3(listx(j),listy(j),pltcol(i1),axesflag=0)
      end
   else
      if nbars > 1 then
         yext=[yext1 interpln([xdeb+width_bars*[0:nobs-1] ; yi'],[xdeb:xdeb+width_bars*(nobs-1)]) yext2]
      else
         yext=[yext1 yi' yext2]
      end
      xset("thickness",1+(nbars~=0))
      [listx,listy]=dealyna(yext)
 
      for j=1:length(listx)
         listx_j=listx(j)
         listy_j=listy(j)
         if j==1 then
            listx_j=listx_j(xdeb:$)
            listy_j=listy_j(xdeb:$)
         end
         if j==length(listx) then
            listx_j=listx_j(1:size(listx_j,2)-xending)
            listy_j=listy_j(1:size(listy_j,2)-xending)
         end
         plot2d(listx_j,listy_j,pltcol(i1),axesflag=0)
      end
   end
end
 
xset("thickness",1)
xset("line style",1)
 
y0=drawy(y(:,y_1),font_axis,y0)
 
drawx(xscale0,max(nbars+bool2s(nbars>2),1),ref_nbinter,font_axis,y0,max(0,-min_x0+1),max(0,max_x0-nobs))
 
if secondaxis then
// remove the na values from series on each axis and
// determine min and max of series on each axis
   y1_nonna=y(:,y_1)
   y1_nonna=y1_nonna(:)
   y1_nonna=y1_nonna(~isnan(y1_nonna))
   maxy1=max(y1_nonna)
   miny1=min(y1_nonna)
   y2_nonna=y(:,y_2)
   y2_nonna=y2_nonna(:)
   y2_nonna=y2_nonna(~isnan(y2_nonna))
   maxy2=max(y2_nonna)
   miny2=min(y2_nonna)
 
// determine the scaling factor applying to series on axis # 2
   ny2=size(y_2,2)
   den=(maxy2-miny2)
   cte=(miny1*maxy2-maxy1*miny2)/den
   deriv=(maxy1-miny1)/den
 
   y2=y(:,y_2)*deriv+cte
 
   for i=1:ny2
      i2=y_2(i)
      xset("line style",sty(i2))
      yi=y2(:,i)
      if bars(i2) == 1 then
         bari=bari+1
         xset("thickness",1)
         yext=[yext1 ; yi .*. [0*[1:bari-1]' ; 1 ; 0*[bari+1:nbars+bool2s(nbars>2)]' ] yext2]
         [listx,listy]=dealyna(yext)
         for j=1:length(listx)
            plot2d3(listx(j),listy(j),pltcol(i2),axesflag=0)
         end
      else
         if nbars > 1 then
            yext=[yext1 interpln([xdeb+width_bars*[0:nobs-1] ; yi'],[xdeb:xdeb+width_bars*(nobs-1)]) yext2]
         else
            yext=[yext1 yi' yext2]
         end
         xset("thickness",1+(nbars~=0))
         [listx,listy]=dealyna(yext)
 
         for j=1:length(listx)
            listx_j=listx(j)
            listy_j=listy(j)
            if j==1 then
               listx_j=listx_j(xdeb:$)
               listy_j=listy_j(xdeb:$)
            end
            if j==length(listx) then
               listx_j=listx_j(1:size(listx_j,2)-xending)
               listy_j=listy_j(1:size(listy_j,2)-xending)
            end
            plot2d(listx_j,listy_j,pltcol(i2),axesflag=0)
         end
      end
   end
   newscale=yscale(y(:,y_2),just_scale)
   scale=newscale*deriv+cte
   xset("line style",1)
   if just_scale then
      drawaxis(y=scale,x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=string(newscale))
      drawaxis(y=[miny1 scale(1)],x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=emptystr(2,1))
      drawaxis(y=[scale(size(scale,2)) maxy1],x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=emptystr(2,1))
   else
      drawaxis(y=scale,x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=string(newscale))
   end
end
 
if exists('legend0','local') then
   if styleg >5 then
      styleg=5
   end
   legends(legend0,[evstr(pltcol) ; sty],styleg)
end
 
set("old_style","off")
 
endfunction
