function []=mpltseries(varargin)
 
// PURPOSE: Mutliple graphs on one window
// ------------------------------------------------------------
// INPUT:
// * (optional) varargin:
//   - a time series
//   - a real (nxp) vector
//   - a string equal to the name of a time series or a (nxp)
//     real vector between quotes
//   - a matrix or a list of such elements
//   - 'nseries = xx' number series per graph
//   - 'ncol = xx' graph page's number of columns  (default = 2)
//   - 'order=x' order of appearance of the series in the graphs.
//      Default (x=-1): the whole list of data is decomposed into b=p/nseries consecutive
//      blocks (B) so that graph number i contains series (B_1(:,i),...B_b(:,i)).
//      The user can use this option in the following way:
//      * x = (1 x p) or (p x 1) vector containing the user defined order of appearance of each serie
//      * x = 0 means that the series are ploted according to their order
//        of appearance in the function call
//   - 'title=x' if the user wants to give its own title
//     (default: the name of the ts if it has been given
//     between quotes, the string 'ts' if not)
//   - 'title_page=x' if the user wants to give its own title to the graph page
//   - 'bounds=[''b1'' ; ''b2'' ;...; ''bn'']' if the user
//     wants to give its own grocer_bounds
//     (default: the whole series)
//   - 'yaxex=xx' if the user wants to put the x axis at value
//      xx (default: y minimum value)
//   - 'yaxis=xx' where xx is a (1xp) matrix of 1 and 2, if the
//      user wants 2 axes, respectively at the left and the
//      right of the graph; the j the series is represented on
//      the left axis if xx(j)==1 and on the right one if
//      xx(j)==2
//      (default: only a left axis)
//   - 'bars = xx' with xx integer row vector of size p
//     representing the nature of the representation of the
//     series (1=bars; anything else = curves)
//   - 'x0(1)=xx' with xx integer representing the x location
//     of the first y axis (default: put at x=1)
//   - 'x0(2)=xx' with xx integer representing the x location
//     of the second y axis (default: put at x=nobs)
//   - 'x=xx' where xx is the (1xnobs) string vector to put
//     on the x axis
//   - 'styleg =xx' with xx integer row vector of size p
//     representing the location of the legend
//     (default: 5, that is the legend is placed interactively
//   - 'style = xx' with xx integer row vector of size p
//     representing the line style of each series
//   - 'color = xx' with xx integer row vector of size p
//      representing the line color of each series
//   - 'thickn = xx' with xx integer row vector of size p
//     representing the thickness of the line drawn for each
//     series (default all equal to 1)
//   - 'page_leg = xx' with title of the legend of the page graph
//   - 'font_title=xx' with xx the size of the title font
//   - 'font_page_title=xx' with xx the size of the title page font
//   - 'font_axis=xx' with xx the size of the axis font
//   - 'font_leg=xx' with xx the size of the legend font
//   - 'window=x' if the user wants to specify the # x where
//     the graph is plotted
//     (default: the window 1)
//   - 'dropna' if the user wants to graph only the non NA
//     values
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the graphic window
// ------------------------------------------------------------
// Copyright: Eric Dubois / Emmanuel Michaux 2008
 
 
 
grocer_nargin=length(varargin)
// set defaults
grocer_wind=1
grocer_y=[]
grocer_leg=%t
grocer_y0=[]
grocer_l=list()
grocer_dropna=%f
grocer_ncol=1
grocer_nseries=1
grocer_styleg0='styleg=6'
grocer_font_leg=2
grocer_f_leg=2
grocer_dumtitp=%f
grocer_dumpleg=%f
grocer_dumftitle=%t
grocer_dumftitp=%t
grocer_dumthickn0=%t
grocer_dumfaxis=%t
grocer_dumsty0=%t
grocer_order=-1
 
for grocer_i=length(varargin):-1:1
   grocer_argi=varargin(grocer_i)
   if typeof(grocer_argi) == 'string' then
      grocer_argis=strsubst(grocer_argi,' ','')
      grocer_str2=part(grocer_argis,1:2)
      grocer_str3=part(grocer_argis,1:3)
      grocer_str4=part(grocer_argis,1:4)
      grocer_str5=part(grocer_argis,1:5)
      grocer_str6=part(grocer_argis,1:6)
      grocer_str7=part(grocer_argis,1:7)
      grocer_str8=part(grocer_argis,1:8)
      grocer_str9=part(grocer_argis,1:9)
      grocer_str10=part(grocer_argis,1:10)
      grocer_str15=part(grocer_argis,1:15)
      grocer_length=length(grocer_argi)
      grocer_endc=part(grocer_argi,strindex(varargin(grocer_i),'=')+1:grocer_length)
      select grocer_str10
      case 'font_title' then
        grocer_f_title='f_title='+string(grocer_endc)
        grocer_dumftitle=%f
        varargin(grocer_i)=null()
      case 'page_title' then
        grocer_titp=grocer_endc
        grocer_dumtitp=%t
        varargin(grocer_i)=null()
      else
        select grocer_str8
        case 'font_leg' then
          grocer_font_leg=evstr(grocer_endc)
          varargin(grocer_i)=null()
        case 'page_leg' then
            grocer_dumpleg=%t
            grocer_strleg=str2vec(varargin(grocer_i))
            varargin(grocer_i)=null()
        else
          select grocer_str6
          case 'bounds' then
             grocer_boundsvar=evstr(grocer_endc)
             varargin(grocer_i)=null()
          case 'window' then
             grocer_wind=evstr(grocer_endc)
             varargin(grocer_i)=null()
          case 'thickn' then
             execstr('grocer_'+string(varargin(grocer_i)))
             grocer_thickn0=string(varargin(grocer_i))
             grocer_dumthickn0=%f
             varargin(grocer_i)=null()
          case 'styleg' then
             grocer_styleg0=string(varargin(grocer_i))
             varargin(grocer_i)=null()
          else
             select grocer_str5
             case 'yaxex' then
                grocer_y0=evstr(grocer_endc)
                varargin(grocer_i)=null()
             case 'yaxis' then
                grocer_yax=varargin(grocer_i)
                varargin(grocer_i)=null()
             case 'title' then
                grocer_tit=strsubst(varargin(grocer_i),',',';')
                grocer_tit=str2vec(grocer_tit)
                varargin(grocer_i)=null()
             case 'noleg' then
                grocer_leg=%f
                varargin(grocer_i)=null()
             case 'color' then
                grocer_pltcol=evstr(grocer_endc)
             case 'style' then
                execstr('grocer_'+string(varargin(grocer_i)))
                grocer_style0=string(varargin(grocer_i))
                grocer_dumsty0=%f
                varargin(grocer_i)=null()
             case 'order' then
                execstr('grocer_'+string(varargin(grocer_i)))
                varargin(grocer_i)=null()
             else
                if grocer_argis == 'dropna' then
                   grocer_dropna=%t
                   varargin(grocer_i)=null()
                elseif grocer_str2 == 'x=' then
                   grocer_xscale0=evstr(grocer_endc)
                   varargin(grocer_i)=null()
                elseif grocer_str3 == 'leg' then
                   grocer_strleg=str2vec(varargin(grocer_i))
                   varargin(grocer_i)=null()
                elseif grocer_str4 == 'ncol' then
                   grocer_ncol=evstr(grocer_endc)
                   varargin(grocer_i)=null()
                elseif grocer_str7 == 'nseries' then
                   grocer_nseries=evstr(grocer_endc)
                   varargin(grocer_i)=null()
                elseif grocer_str9 == 'font_axis' then
                    grocer_f_axis='font_axis='+string(grocer_endc)
                    grocer_dumfaxis=%f
                    varargin(grocer_i)=null()
                elseif grocer_str15 == 'font_page_title' then
                    execstr('grocer_'+string(varargin(grocer_i)))
                    grocer_dumftitp=%f
                    varargin(grocer_i)=null()
                elseif grocer_str5 ~= 'color' & grocer_str5 ~= 'style' & grocer_str4 ~= 'bars' ...
                   & grocer_str2 ~= 'x0' & part(grocer_argis,1:11) ~= 'just_scale=' ...
                   & grocer_str6 ~= 'thickn' & grocer_str9 ~= 'font_leg=' then
                    grocer_l($+1)=varargin(grocer_i)
                    varargin(grocer_i)=null()
                end
              end
            end
         end
      end
   elseif (typeof(varargin(grocer_i)) == 'constant') | (typeof(varargin(grocer_i))=='tsmat') then
      grocer_l($+1)=varargin(grocer_i)
      varargin(grocer_i)=null()
   end
end
 
if exists('grocer_boundsvar','local') then
// ! warning: where they are written, these lines of code
// allow one to draw ts which are defined only as a vector
// very useful (cf. garch.sci), but a little bit dangerous !
   if size(grocer_boundsvar,2) ~= 1  then
      if size(grocer_boundsvar,1) == 1 then
         grocer_boundsvar=grocer_boundsvar'
      else
         error('your grocer_bounds are not a vector of strings')
      end
   end
   for i=1:size(grocer_boundsvar,1)/2
      [d1,fq]=date2num_fq(grocer_boundsvar(i*2-1))
      grocer_xscale0=num2date([d1:d1+diff_date(grocer_boundsvar(2*i),...
           grocer_boundsvar(2*i-1))]',date2fq(grocer_boundsvar(i*2-1)))'
   end
else
   grocer_boundsvar=[]
end
 
grocer_lb=list()
for i=1:length(grocer_l)
   grocer_lb($+1)=grocer_l(length(grocer_l)+1-i)
end
 
[grocer_y,grocer_namexos,grocer_prests,grocer_boundsvarb]=...
      explone(grocer_lb,grocer_boundsvar,'series',%f,grocer_dropna)
 
// number of series
nobs=size(grocer_y,1)
if length(grocer_nseries)==[]
  grocer_nseries=size(grocer_y,2)
end
 
// size of the title
if grocer_dumftitle & grocer_dumpleg then
  grocer_f_title='f_title=2'
elseif  grocer_dumftitle & ~grocer_dumpleg then
  grocer_f_title=emptystr()
end
 
// size of the axis font
if grocer_dumfaxis then
  grocer_f_axis='font_axis=2'
end
 
// thickness of lines
if grocer_dumthickn0 then
  th='[1'
  if grocer_nseries>1 then
    for i=1:(grocer_nseries-1)
      th=th+',1'
    end
  end
  th=th+']'
  grocer_thickn0='thickn='+string(th)
  grocer_thickn=ones(1,grocer_nseries)
end
 
// size of the legend page
if grocer_dumtitp & grocer_dumftitp then
  grocer_font_page_title=max(1,5-floor(length(grocer_titp)/20))
end
 
// style of lines
// The code below is temporary and should fix the
// following bug in pltseries:
//  with subplot, axes inherate style properties
//  of lines so each curve is drawn with line_style=1
if ~grocer_dumsty0 then
  if size(grocer_style,1)>size(grocer_style,2) then
    grocer_style=grocer_style'
  end
elseif grocer_dumsty0 then
  ty='[1'
  if grocer_nseries>1 then
    for i=1:(grocer_nseries-1)
      ty=ty+',1'
    end
  end
  ty=ty+']'
  grocer_style0='style='+string(ty)
  grocer_style=ones(1,grocer_nseries)
end
 
// if the user has not given any x axis legend, then generate it
if ~exists('grocer_xscale0','local') then
   if grocer_prests then
      dn=date2num_m(grocer_boundsvarb)
      dscale=[]
      for i=1:size(dn,1)/2
         dscale=[dscale dn(2*i-1):dn(2*i)]
      end
      grocer_xscale0=num2date(dscale,date2fq(grocer_boundsvarb(1)))
   else
      grocer_xscale0=string([1:nobs])
   end
end
 
if grocer_dropna then
// drop na from the series and from the scale
   nonna=or(isnan(grocer_y),'c')
   grocer_y=grocer_y(~nonna,:)
   grocer_xscale0=grocer_xscale0(~nonna)
end
 
// open a new window
if length(grocer_wind)==0 then
  grocer_wind=winsid()
  grocer_wind=grocer_wind($)+1
end
xset("window",grocer_wind)
xbasc(grocer_wind)
 
// number of graph to compute
grocer_k=size(grocer_y,2)
grocer_ny = grocer_k/grocer_nseries
if round(grocer_ny) ~= grocer_ny then
  error("Wrong number of graphs")
end
grocer_nplot=grocer_ny
 
// add a window for the legend if necessary
if grocer_leg & grocer_dumpleg then
  grocer_nplot=grocer_nplot+1
end
 
// add a window for the graph page title if necessary
begg=0
if grocer_dumtitp then
  grocer_nplot=grocer_nplot+1
  begg=1
end
 
if int(grocer_nplot/grocer_ncol) ~= (grocer_nplot/grocer_ncol)
  grocer_nplot=grocer_nplot+1
end
grocer_nl=grocer_nplot/grocer_ncol
 
if grocer_order==-1 then
  seld=matrix(1:grocer_k,grocer_ny,grocer_nseries)
elseif grocer_order==1 then
  seld=matrix(1:grocer_k,grocer_nseries,grocer_ny)'
elseif size(grocer_order,'*')==grocer_k then
  seld=grocer_order
else
  error("Size of vector "'order'" don''t match with the number of series")
end
 
// if the user has not given any tittle, then generate it
if ~exists('grocer_tit','local') then
   grocer_tit=emptystr(grocer_ny,1)
end
 
// number of y-axis
if ~exists('grocer_yax','local') then
   grocer_yax='yaxis=['+joinstr(string(ones(1,grocer_nseries)),',')+']'
end
 
// graphs legend
if ~exists('grocer_strleg','local') & grocer_leg & ~grocer_dumpleg then
  if exists('grocer_yax','local') then
    execstr(grocer_yax)
    // test size of yaxis option
    if (size(yaxis,'*')>1) & (grocer_nseries==1) then
      error("No 2nd axis is needed when each only one serie is drawn on each graph")
    else
      if size(yaxis,1)~=grocer_k then
        if size(yaxis,2)==grocer_k then
          yaxis=yaxis'
        elseif size(yaxis,'*')==grocer_nseries then
          yaxis=yaxis'.*.ones(grocer_ny,1)
        else
          error("Size of the the legend don''t match with the # of series")
        end
      end
    end
 
    yaxis=string(yaxis)
    yaxis=strsubst(yaxis,'1','lhs')
    yaxis=strsubst(yaxis,'2','rhs')
    grocer_strleg0=grocer_namexos+' ('+yaxis+')'
  else
    grocer_strleg0=grocer_namexos
  end
end
 
// draw page graph title if necessary
if grocer_dumtitp then
  drawlater()
  subplot(grocer_nl,grocer_ncol,1)
  plot2d([0,1],[0,1],[-1,-1],"010",rect=[0,0,1,1])
  ha=gca()
  hlt=ha.title
  hlt.text=grocer_titp
  hlt.font_size=grocer_font_page_title
  hlt.auto_position="off"
  hlt.position=[0.3,0.5]
  drawnow()
end
 
// draw graphs
if ~grocer_dumpleg & grocer_leg then
  for t=1:grocer_ny
    grocer_strleg='['+joinstr(grocer_strleg0(seld(t,:)),';')+']'
    subplot(grocer_nl,grocer_ncol,t+begg)
    pltseries0(grocer_y(:,seld(t,:)),grocer_y0,grocer_tit(t),grocer_xscale0,-1,grocer_yax,...
    grocer_f_title,grocer_f_axis,grocer_thickn0,grocer_style0,...
    'leg='+grocer_strleg,grocer_styleg0,varargin(:))
  end
else
  for t=1:grocer_ny
    subplot(grocer_nl,grocer_ncol,t+begg)
    pltseries0(grocer_y(:,seld(t,:)),grocer_y0,grocer_tit(t),grocer_xscale0,-1,grocer_yax,...
    grocer_f_title,grocer_f_axis,grocer_thickn0,grocer_style0,varargin(:))
  end
end
 
// draw a global legend if necessary
if grocer_leg & grocer_dumpleg then
  if size(grocer_strleg,'*')~=grocer_nseries
    error("Number of arguments in legend not equal to the number of series")
  end
 
  if ~exists('grocer_pltcol','local') then
    grocer_pltcol=[1 2 5 14 24 3:4 6:13];
	grocer_pltcol=grocer_pltcol(1:grocer_nseries);
  end
 
  drawlater()
  subplot(grocer_nl,grocer_ncol,t+begg+1)
  plot2d(zeros(4,1),zeros(4,grocer_nseries),grocer_pltcol,"010")
  legends_groc(grocer_strleg,[evstr(grocer_pltcol);grocer_style],2,with_box=%f,grocer_font_leg)
  h=gce()
  nleg=size(grocer_strleg,'*');
  for i=1:nleg
    hi=h.children(2*(nleg-i+1));
    hi.thickness=grocer_thickn(i);
    hi.line_style=grocer_style(i);
  end
  drawnow()
end
endfunction
