function []=prtjohan(res,boots,out)
 
// PURPOSE: prints the results of a Johansen cointegration test
// on the file out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a johansen regression
// * boots = a string, the kind of p-value that will be used
//   ('fast' -default for fast fouble bootsrap, anyhthing else
//    for the simple bootstrap)
// * out = the symobolic name of the file where the
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// NOTES:
// used by the following function:
// johansen()
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2009
// http://dubois.ensae.net/grocer.html
 
 
 
[nargout,nargin] = argn(0)
select nargin
case 1 then
   out=%io(2)
   boots='fast'
case 2 then
   out=%io(2)
end
 
lr1=res('lr1')
lr2=res('lr2')
nvar=res('nvar')
 
if boots == 'fast' then
   lr1_p=res('p double trace')
   lr2_p=res('p double lmax')
else
   lr1_p=res('p trace')
   lr2_p=res('p lmax')
end
 
write(out,' ')
write(out,'Johansen estimation results for variables:')
write(out,joinstr(res('namey'),', '))
write(out,' ')
write(out,'exogenous variables restricted to lie in the cointegration space:')
if isempty(res('namexo_lt')) then
  write(out,'none')
else
  write(out,strcat(res('namexo_lt'),', '))
end
write(out,'unrestricted exogenous variables:')
write(out,' ')
if isempty(res('namexo_st')) then
  write(out,'none')
else
  write(out,strcat(res('namexo_st'),', '))
end
write(out,' ')
write(out,'# of lags: '+string(res('nlags')))
 
write(out,' ')
 
mat2prt=['lambda'+string([1:nvar]') string(res('eig')) ]
printmat(mat2prt,out)
 
write(out,' ')
mat2prt=['NULL:   ' 'Trace Statistic'  'p-value';...
          ['r = 0 ' 'r <= '+string([1:nvar-1])]' string([lr1 lr1_p]) ]
printmat(mat2prt,out)
 
write(out,' ')
write(out,'conclusions from the trace statistics:')
 
vaux=find([ lr1_p ; 1 ]> 0.1)
nrel=vaux(1)-1
write(out,'at a 10% level, there are '+string(nrel)+' cointegration relation(s)')
 
vaux=find([ lr1_p ; 1 ]> 0.05)
nrel=vaux(1)-1
write(out,'at a 5% level, there are '+string(nrel)+' cointegration relation(s)')
 
vaux=find([ lr1_p ; 1 ]> 0.01)
nrel=vaux(1)-1
write(out,'at a 1% level, there are '+string(nrel)+' cointegration relation(s)')
 
write(out,' ')
mat2prt=['NULL:   ' 'Max Eigenvalues Statistic ' 'p-value';...
         'l <= '+string([0:nvar-1]') string([lr2 lr2_p]) ]
printmat(mat2prt,out)
 
write(out,' ')
write(out,'conclusions from the maximal eigenvalues statistics:')
 
vaux=find([0; lr2_p ] < 0.1)
nrel=vaux($)-1
write(out,'at a 10% level, there are '+string(nrel)+' cointegration relation(s)')
 
vaux=find([0; lr2_p ] < 0.05)
nrel=vaux($)-1
write(out,'at a 5% level, there are '+string(nrel)+' cointegration relation(s)')
 
vaux=find([0; lr2_p ] < 0.01)
nrel=vaux($)-1
write(out,'at a 1% level, there are '+string(nrel)+' cointegration relation(s)')
 
printsep(out)
 
endfunction
