function prtms(r,out);
 
// PURPOSE: print a MS-VAR set of parameters in a readable form
// ------------------------------------------------------------
// INPUT:
// * r = the results typed list of a univariate regression
// * out = the symobolic name of the file where the
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// Adapted to Scilab by Eric Dubois
// http://dubois.ensae.net/grocer.html
// from Gauss library MSVarlib 2.0
// Copyright (C) 2004 by Benoit BELLONE.
// http://bellone.ensae.net
// All rights reserved
 
[nargout,nargin]=argn(0)
if nargin == 1 then
   out=%io(2)
end
 
meth=r('meth')
namex_id=r('namex_id')
namey=r('namey')
beta_id=r('beta_id')
beta_id_tstat=r('beta_id_tstat')
beta_id_p=r('beta_id_pvalue')
sigma=r('sigma')
n_endo=r('nendo')
n_x=size(r('namex_id'),1)
n_z=0
 
if meth ~= 'ms mean' then
   namex_co=r('namex_co')
   beta_co=r('beta_co')
   beta_co_tstat=r('beta_co_tstat')
   beta_co_p=r('beta_co_pvalue')
   n_z=size(beta_co,1)
end
 
ptrans=r('ptrans')
K=r('nendo')
M=r('nb_states')
ptrans=r('ptrans')
ptrans_tstat=r('ptrans_tstat')
ptrans_pvalue=r('ptrans_pvalue')
nvar=size(r('coeff'),1)
 
write(out,meth+" estimation results")
write(out," ")
if r('prests') then
   ch='estimation period: '
   boundsvar=r('bounds')
   for i=1:size(boundsvar,1)/2
      ch=ch+boundsvar(2*i-1)+'-'+boundsvar(2*i)+'  '
   end
   write(out,ch)
end
write(out,'number of observations: '+string(r('nobs')))
write(out,'number of variables: '+string(nvar))
 
write(out,"Log likelihood: "+string(r('llike')))
 
write(out,"Degree of freedom: "+string(r('dll')));
write(out,' ')
write(out,' ')
 
write(out,"=================Matrix of markovian transition probabilities P[i,j]: ==================");
write(out,"=================                [tstat - p-value]                    =================");
write(out,' ')
mat2print=emptystr(M*3,M+1)
mat2print(3*[1:M]-2,2:M+1)=string(ptrans)
mat2print(3*[1:M]-1,2:M+1)='['+string(round(ptrans_tstat*100)/100)+' - '+string(ptrans_pvalue)+']'
 
printmat(mat2print,out)
write(out,' ')
write(out,"================= Ergodic probabilities :=================")
write(out,' ')
printmat(string(r('prob_st')),out)
write(out,' ')
write(out,"================= Coefficients ")
write(out,' ')
 
if ~isempty(r('namex_co')) then
   write(out,"============== All Regimes =============")
   labels=['exogenous' 'coeff' 't-statistic' 'p value']
   mat2print=emptystr((n_z+2)*K+1,4)+' '
   mat2print(1,:)=labels
   mat2print(3+(n_z+2)*[0:K-1],1)='*** for endogenous: '+namey+' ***'
   for k=0:K-1
      mat2print([4:(3+n_z)]+(n_z+2)*k,1)=namex_co
   end
   mat2print(ones(K,1) .*. [4:(3+n_z)]'  + (n_z+2)*([0:K-1]' .*. ones(n_z,1)),2)=...
      string(matrix(beta_co,1,K*n_z))'
   mat2print(ones(K,1) .*. [4:(3+n_z)]'  + (n_z+2)*([0:K-1]' .*. ones(n_z,1)),3)=...
      string(matrix(beta_co_tstat,1,K*n_z))'
   mat2print(ones(K,1) .*. [4:(3+n_z)]'  + (n_z+2)*([0:K-1]' .*. ones(n_z,1)),4)=...
      string(matrix(beta_co_p,1,K*n_z))'
   printmat(mat2print,out)
   write(out,' ')
   write(out,' ')
end
 
for j=0:M-1
   write(out,"============== Regime "+string(j+1)+" =============")
   write(out,' ')
   if n_x ~= 0 then
      labels=['exogenous' 'coeff' 't-statistic' 'p value']
      mat2print=emptystr(K*(n_x+2)+1,4)+' '
      mat2print(1,1:4)=labels
      mat2print(3+(n_x+2)*[0:K-1],1)='*** for endogenous: '+namey+' ***'
      for k=0:K-1
         mat2print([4:(3+n_x)]+(n_x+2)*k,1)=namex_id
      end
      mat2print([4:(3+n_x)]' .*. ones(K,1) + (n_x+2)*(ones(n_x,1) .*. [0:K-1]'),2)=...
         string(matrix(beta_id(:,j*K+1:(j+1)*K),1,K*n_x))'
      mat2print([4:(3+n_x)]' .*. ones(K,1) + (n_x+2)*(ones(n_x,1) .*. [0:K-1]'),3)=...
         string(matrix(beta_id_tstat(:,j*K+1:(j+1)*K),1,K*n_x))'
      mat2print([4:(3+n_x)]' .*. ones(K,1) + (n_x+2)*(ones(n_x,1) .*. [0:K-1]'),4)=...
         string(matrix(beta_id_p(:,j*K+1:(j+1)*K),1,K*n_x))'
      printmat(mat2print,out)
   end
   
   ns=size(sigma,1)
   if r('switching V') ~= 1 then
      write(out,' ')
 
      write(out,"Variance-covariance matrix of residuals")
      write(out,"           [tstat - p-value]           ");
      mat2print=emptystr(K*3,K+1)
      mat2print(3*[1:K]-1,2:K+1)=string(r('sigma')(:,K*j+1:K*(j+1)))
      mat2print(3*[1:K],2:K+1)='['+string(round(r('sigma_tstat')(:,K*j+1:K*(j+1))*100)/100)+' - '+string(r('sigma_pvalue')(:,K*j+1:K*(j+1)))+']'
 
      if K==1 then
         mat2print=[emptystr(3,1)+'          ' mat2print]
      end
 
      printmat(mat2print,out)
   end
   write(out,' ')
   write(out,' ')
end
 
if  r('switching V') == 1 then
   write(out,' ')
 
   write(out,"============== Variance-covariance matrix of residuals for all regimes ============== ")
   write(out,"==============                  [tstat - p-value]                      ==============");
   write(out,' ')
   mat2print=emptystr(K*3,K+1)
   mat2print(3*[1:K]-2,2:K+1)=string(r('sigma'))
   mat2print(3*[1:K]-1,2:K+1)='['+string(round(r('sigma_tstat')*100)/100)+' - '+string(r('sigma_pvalue'))+']'
 
  if K==1 then
      mat2print=[emptystr(3,1)+'          ' mat2print]
   end
 
   printmat(mat2print,out)
end
 
endfunction
 
