function []=prtuniv(res,out)
 
// PURPOSE: prints the results of univariate regression on
// the file out
// ------------------------------------------------------------
// INPUT:
// * res = the results typed list of a univariate regression
// * out = the symobolic name of the file where the
//              results are printed (default: %io(2))
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the specified file
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2007
// http://dubois.ensae.net/grocer.html
 
 
 
[nargout,nargin] = argn(0)
if nargin == 1 then
   out=%io(2)
end
 
if part(convstr(getversion()),1:9) == 'scilab-5.' then
   matspec=[' ' ' ']
else
   matspec=' '
end
 
meth=res('meth')
bet=res('beta')
namex=res('namex')
nvar=res('nvar')
 
panel=or(['panel pooled'; 'panel with fixed effects';'panel with random effects';'between'] == meth)
 
write(out,' ')
select meth
 
case 'nls' then
   write(out,meth+' estimation results for equation:')
   write(out,res('namey'))
 
case 'cadf' then
   write(out,' ')
   write(out,'cadf RESULTS ESTIMATION')
   write(out,' ')
   write(out,'-----------------------------------------------------')
   write(out,'RESULTS FROM THE FIRST STAGE COINTEGRATING REGRESSION')
   write(out,'-----------------------------------------------------')
   write(out,' ')
   prtuniv(res('cointrel'))
   res('pvalue') = string(res('pvalue'))
   res('pvalue')(1) = '(*)'
   r1=res('cointrel')
   namexc=r1('namex')
   namexp=namexc(1)
   for i=2:size(namexc,2)
      namexp=namexp+', '+namexc(i)
   end
   write(out,' ')
   write(out,'-----------------------------------------------------------------------------')
   write(out,'RESULTS FROM THE cadf SECOND STAGE REGRESSION ON RESIDUALS OF THE FIRST STAGE')
   write(out,'-----------------------------------------------------------------------------')
   write(out,' ')
 
case 'ers' then
   write(out,meth+' estimation results for dependent variable: '+res('namey'))
   if res('trend') == 0 then
      txt='with constant'
   else
      txt='with constant + trend'
   end
   write(out,'model '+txt)
 
else
   write(out,meth+' estimation results for dependent variable: '+res('namey'))
 
end
 
if or(meth == ['twosls' 'threesls' 'iv']) then
   write(out,' ')
   if max(size(res('nameendo'))) == 0 then
      if meth == 'threesls' then
         write(out,'there is no endogenous variable in the equation')
      else
         write(out,'there is no endogenous variable in the equation: iv=ols')
      end
   else
      write(out,'endogenous variable(s) in this equation is(are):')
      write(out,joinstr(res('nameendo'),','))
      write(out,' ')
      write(out,'instruments for this equation are:')
      write(out,joinstr(res('nameinst'),','))
   end
   write(out,' ')
 
elseif meth == 'constrained ols' then
   write(out,'with constraints of the type: Rb=r')
   write(out,'and R =')
   printmat(string(res('R')),out)
   write(out,' ')
   write(out,'and r =')
   printmat(string(res('r')),out)
   write(out,' ')
 
end
 
if ~panel then
   if res('prests') then
      ch='estimation period: '
      boundsvar=res('bounds')
      for i=1:size(boundsvar,1)/2
         ch=ch+boundsvar(2*i-1)+'-'+boundsvar(2*i)+' '
      end
      if res('dropna') then
         ch=ch+'(NA values dropped)'
      end
      write(out,ch)
   end
end
 
write(out,'number of observations: '+string(res('nobs')))
write(out,'number of variables: '+string(nvar))
if or(meth == ['logit' ; 'probit' ;'multilogit' ; 'ordered logit'; 'ordered probit']) then
   matspec(1)='McFadden R = '+string(res('r2mf'))
   write(out,matspec)
   matspec(1)='Estrella R = '+string(res('rsqr'))
   write(out,matspec)
   write(out,'log-likelihood = '+string(res('llike')));
   write(out,'LR-ratio = 2*(Lu-Lr) = '+string(res('lratio')))
   write(out,'LR p-value  = '+string(1-cdfchi("PQ",...
   res('lratio'),nvar-1)))
else
   if res('prescte')  & nvar > 1 then
      if meth == 'twosls' | meth == 'threesls' ...
         | meth == 'iv'  then
         matspec(1)='generalized R = '+string(res('grsqr'))+'  adjusted generalized R ='+string(res('grbar'))
      else
           matspec(1)='R = '+string(res('rsqr'))+'  adjusted R ='+string(res('rbar'))
      end
      write(out,matspec)
      fi="Overall F test: F("+string(nvar-1)+","+...
      string(res('nobs')-nvar)+") = "+string(res('f'))+...
      "       p-value = "+string(res('pvaluef'))
      write(out,fi)
   end
   write(out,'standard error of the regression: '+...
   string(res('ser')))
   write(out,'sum of squared residuals: '+string(res('sigu')))
   if ~panel then
      write(out,'DW(0) ='+string(res('dw')))
   end
end
 
if meth ~= 'nls' then
   write(out,'Belsley, Kuh, Welsch Condition index: '+...
   string(res('condindex')))
end
 
if meth == 'garch' then
 
   write(%io(2),'log likelihood: '+string(like))
   write(out,[' '])
 
elseif meth == 'Theil-Goldberger' then
 
   write(out,[' '])
   mat2print=['Prior Mean' 'Std Deviation';...
              string(res('pmean')) string(res('pstd'))]
   printmat(mat2print,out)
   write(out,[' '])
 
end
 
write(out,[' '])
if meth == 'multilogit' then
   ncat=res('ncat')
   tstat=res('tstat')
   pvalue=res('pvalue')
   mat2print=['variable' 'coeff' 't-statistic' 'p value' ; ' ' ' ' ' ' ' ']
   for j=1:ncat
      mat2print=[mat2print ; 'category # '+string(j) ' ' ' ' ' ';...
         '------------' ' ' ' ' ' ' ;...
         namex string([bet(:,j) tstat(:,j) pvalue(:,j)]);...
         ' ' ' ' ' ' ' ']
   end
else
   mat2print=['variable' 'coeff' 't-statistic' 'p value']
   for i=1:nvar
      mat2print=[mat2print ; namex(i) string(bet(i)) string(res('tstat')(i)) string(res('pvalue')(i))]
   end
end
 
if meth == 'ADF' | meth == 'ers' then
   mat2print(2,4) = '(*)'
elseif meth == 'olsecm' then
   mat2print($,4) = '(*)'
end
 
printmat(mat2print,out)
 
if meth == 'Cochrane-Orcutt' | meth == 'ar(1) maximum likelihood' then
   printsep(out)
   write(%io(2),' ')
   mat2print=['rho' string(res('rho')); 't-stat' string(res('trho'))]
   printmat(mat2print,%io(2))
   write(%io(2),' ')
   write(%io(2),'note the all statistics are calculated from the quasi-differentiated model')
   write(%io(2),'because they are generally (t-stats, R, overall F-test in particular) meaningless on the original model')
 
elseif meth == 'garch' then
   if res('prests') then
      b='bounds=['+joinstr('''',res('bounds'),''';')+''']'
      pltseries('sigt',b,'title=estimated variance of residuals','noleg')
   else
      pltseries('sigt','title=estimated variance of residuals','noleg')
   end
end
 
write(out,[' '])
 
if meth == 'ols' then
 
   grocer_comp=0
   for i=1:size(namex,1)
      l=length(namex(i))
      m=part(namex(i),max(l-2,1):l)
      if m == '(*)' then
         grocer_comp=grocer_comp+1
      end
   end
   if grocer_comp == 1 then
      write(out,'(*): variable constrained by the user to be present in the regression')
   elseif grocer_comp > 1 then
      write(out,'(*): variables constrained by the user to be present in the regression')
   end
 
elseif meth == 'panel with random effects' then
 
   write(out,' ')
   write(out,'**************')
   write(out,'random effects')
   write(out,' ')
   m2prt=['individual' 'estimated effect' ; namex(nvar+1:$) string(res('random effects'))]
   printmat(m2prt,out)
 
end
 
printsep(out)
 
res_fields=res(1)
if or(res(1) == 'name_test') then
   write(out,' ')
   write(out,'tests results:')
   write(out,'**************')
   m=['test value' 'p-value']
   m= [m ; string(res('spec_test'))]
   m2prt=[res('name_test') m]
   printmat(m2prt,out)
   write(out,' ')
   printsep(out)
end
 
endfunction
