function [bet,llike]=olsar1_0(y,x)
 
// PURPOSE: computes maximum likelihood ols regression for AR1
// errors
// ------------------------------------------------------------
// INPUT:
// * namey0 = a time series, a real (nx1) vector or a
// string equal to the name of a time series or a (nx1) real
// vector between quotes
// * varargin = arguments which can be:
//   . a time series
//   . a real (nxp) vector
//   . a string equal to the name of a time series or a (nx1)
//     real vector between quotes
//   . the string 'noprint' if the user doesn't want the
//     to print the results of the regression
//---------------------------------------------------
// rolsar1 = a results tlist with
//   . rolsar1('meth')  = ' ar(1) maximum likelihood'
//   . rolsar1('y')     = y data vector
//   . rolsar1('x')     = x data matrix
//   . rolsar1('nobs')  = # observations
//   . rolsar1('nvar')  = # variables
//   . rolsar1('beta')  = bhat
//   . rolsar1('yhat')  = yhat
//   . rolsar1('resid') = residuals
//   . rolsar1('vcovar') = estimated variance-covariance matrix of
//     beta
//   . rolsar1('sige')  = estimated variance of the residuals
//   . rolsar1('sigu')  = sum of squared residuals
//   . rolsar1('ser')  = standard error of the regression
//   . rolsar1('tstat') = t-stats
//   . rolsar1('pvalue') = pvalue of the betas
//   . rolsar1('dw')    = Durbin-Watson Statistic
//   . rolsar1('condindex') = multicolinearity cond index
//   . rolsar1('prescte') = boolean indicating the presence or
//     absence of a constant in the regression
//   . rolsar1('rsqr')  = rsquared
//   . rolsar1('rbar')  = rbar-squared
//   . rolsar1('f')    = F-stat for the nullity of coefficients
//     other than the constant
//   . rolsar1('pvaluef') = its significance level
//   . rolsar1('prests') = boolean indicating the presence or
//     absence of a time series in the regression
//   . rolsar1('namey') = name of the y variable
//   . rolsar1('namex') = name of the x variables
//   . rolsar1('bounds') = if there is a timeseries in the
//     regression, the bounds of the regression
//   . rolsar1('rho') = estimated first order autocorrelation of residuals
//   . rolsar1('trho') = its Student t
//   . rolsar1('like') = log-likelihood of the regression
// --------------------------------------------------
 
 
 
 
[nobs,nvar] = size(x);
[nobs2] = size(y,1);
 
xtmp = lag(x,1);
ytmp = lag(y,1);
 
// truncate 1st observation to feed the lag
xlag = xtmp(2:nobs,:);
ylag = ytmp(2:nobs,1);
yt = y(2:nobs,1);
xt = x(2:nobs,:);
 
// use cochrane-orcutt estimates as initial values
 
reso = olsc0(y,x,'noprint');
 
parm = zeros(nvar+1,1);
parm(1) = reso('rho');
// initial rho
parm(2:nvar+1) = reso('beta');
// initial bhat's
 
deff('[f,g,ind]=cost(parm,ind)',..
     ['f=ar1_like(parm,y,x)';...
     'g=ar1_grad(parm,y,x)'])
 
binf=[-1+%eps ; -%inf*ones(nvar,1)]
 
[like,bet] = optim(cost,'b',binf,-binf,parm);
llike = -like+nobs/2*(log(nobs)-log(2*%pi))
 
endfunction
