function [p]=statfore(res,varargin)
 
// PURPOSE: provides a static forecast from an equation
// estimated by ols(), hwhite(), olst(), lad(),...
// ------------------------------------------------------------
// INPUT:
// * res = result tlist
// * varargin  =
//   - (optional) subperiod over which the previson is done if
//   variables are ts
//   - a (mxk) matrix of exogenous variables if they are not ts
// ------------------------------------------------------------
// OUTPUT:
// p = prevision
// ------------------------------------------------------------
// NOTES:
// * can be used also with results of olsc (but does not take
//   into account the correlation)
// * cannot be used with results of garch (but this needs only
//   small adaptation)
// * if the estimation has been performed with ts, then the
//   function assumes that the variables have been entered
//   between quotes and that their name has therefore been
//   saved in the tlist
// * in that case, the corresponding data must be present in
//   the environment
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2008
 
 
 
[nargout,nargin]=argn(0)
bet=res('beta')
if res('prests') then
   namex=res('namex')
// replace the constant term, if any, by 1
   namex(find(namex=='cte'))='1'
   namex(find(namex=='const'))='1'
   p=evstr(namex(1))*bet(1)
   for i=2:size(bet,1)
      p=p+evstr(namex(i))*bet(i)
   end
   if nargin ~= 1 then
      p=subper(p,varargin(:))
   end
else
   p=varargin(1)*bet
end
 
endfunction
