function ts=m2a(ts,ind)
 
// PURPOSE: transforms quarterly data into annual ones
// ------------------------------------------------------------
// INPUT:
// * ts = a quarterly timeseries
// * ind =
//   - -1 if the annual data is to be the sum of the
// corresponding quarters
//   - 0 if the  annual data is to be the mean of the
// corresponding quarters
//   - 1 if the annual data is to be the value of the
// first quarter
//   - 2 if the annual data is to be the value of the
// second quarter
//   - 3 if the annual data is to be the value of the
// third quarter
//   - 12 if the annual data is to be the value of the
// fourth quarter
// ind is optional; if not provided, it is set to -1
// ------------------------------------------------------------
// OUTPUT:
// * ts = the corresponding quarterly time series
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2010
// http://dubois.ensae.net/grocer.html
 
 
[nargout,nargin]=argn(0)
if nargin == 1 then
   ind=-1
end

typeof_ts=typeof(ts)
if and(typeof_ts ~= ['ts' 'tsmat']) then
   error('m2q applies only to ts or tsmat and not to '+typeof_ts)
end

if ts('freq') ~= 12 then
   error('your '+typeof_ts+' should have frequency 12')
end    

d=datets(ts)
s=series(ts)
 
if ind < 1 then
  
// retrieve the first quarter of the full year
// and its index in the vectors series, listna or dates
// calculate the number of full years
// and transform the listna and series in order
// to have the 12 quarterly values of one year
// on the rows of the matrix mtrans and natrans
// set div to 1 if ind=-1, to 12 if ind=0
   div=12+11*ind
   deb_q=modulo(d(1)-1,12)
   deb_ind=modulo(12-deb_q,12)+1
   nyears=floor((size(s,1)-deb_ind+1)/12)
   if nyears == 0 then
      disp('in m2a, not enough monthly data to build a year')
   end
   TR=eye(nyears,nyears) .*. ones(1,12)
   deb_y=(d(deb_ind)-1)/12
// calculate and put in an array the annual data
   ts('series')=TR*s(deb_ind:deb_ind-1+12*nyears,:)/div
   
else
  
// deb_ind is the index of the first value belonging to the
// chosen quarter
   deb_ind=1+modulo(12-modulo(d(1)-ind,12),12)
   end_ind=size(d,1)-modulo(d(size(d,1))-ind,12)
   nyears=(end_ind-deb_ind)/12+1
   if nyears == 0 then
      disp('in m2a, not enough quarterly data to build a year')
   end
   deb_y=(d(deb_ind)-ind)/12
// take the series between the first and the last
// existing quarter of the required type and fill with 1
// to obtain a vector with a suitable length (a multiple of
// 12)
   ts('series')=s(deb_ind:12:end_ind,:)
   
end

ts('freq')=1
ts('dates')=[deb_y:deb_y+nyears-1]'

endfunction
