function ts=da2m(ts,ind,dropna)
 
// PURPOSE: transforms daily data into monthly ones
// ------------------------------------------------------------
// INPUT:
// * ts = a daily timeseries
// * ind =
//   - -1 if the monthly data is to be the sum of the
// corresponding days
//   - 0 if the  monthly data is to be the mean of the
// corresponding days
//   - n between 1 and 28 if the monthly data is to be the
//     value of the n-th day of the month
//   - n > 29 if the monthly data is to be the value of the
//     last day of the month
// * dropna = 'dropna' if the user wants to withdraw all NA
//   values from the calculations (case ind=0 or -1) or to take
//   the last non NA value of the quarter (case ind > 90)
// if not entered then all NA values are considered
// ------------------------------------------------------------
// OUTPUT:
// * ts = the corresponding monthly time series
// ------------------------------------------------------------
// Copyright: Eric Dubois 2007
 
 
global GROCERDIR;
 
[nargout,nargin]=argn(0)
if nargin == 1 then
   ind=-1
end
if nargin < 3 then
   dropna=%f
elseif dropna== 'dropna' then
   dropna=%t
end
 
d=datets(ts)
s=series(ts)
k=size(s,2)
 
load(GROCERDIR+'\data\dailyform.dat')
load(GROCERDIR+'\data\basets.dat')
 
dat=num2date(d(1),365)
indsep=strindex(dat,grocer_dailysep)
dat=[part(dat,1:indsep(1)-1);part(dat,indsep(1)+1:indsep(2)-1);...
part(dat,indsep(2)+1:length(dat))]
year=dat(grocer_dailypart(1))
month=evstr(dat(grocer_dailypart(2)))
day=evstr(dat(grocer_dailypart(3)))
 
if ind < 1 then
// retrieve the first day of the full month
// and its index in the vectors series, listna or dates
// calculate the index of the first and of the last full months
 
   if day == 1 then
      // the first date is the beginning of a month
      ind_start=1
      m0=dat(grocer_dailypart(2))
   else
      if month == 12 then
         // the first full month begins the year after
         year=string(evstr(year)+1)
         m0='01'
      elseif month < 10 then
         m0='0'+string(month+1)
      else
         m0=string(month+1)
      end
 
      day='01'
      newdat=emptystr(3,1)
      newdat(grocer_dailypart(1))=year
      newdat(grocer_dailypart(2))=m0
      newdat(grocer_dailypart(3))=day
      datn=newdat(1)+grocer_dailysep+newdat(2)+grocer_dailysep+newdat(3)
      ind_start=date2num(datn)-d(1)+1
   end
 
   ind_end=size(d,1)
   dat=num2date(d(ind_end)+1,365)
   dat=[part(dat,1:indsep(1)-1);part(dat,indsep(1)+1:indsep(2)-1);...
   part(dat,indsep(2)+1:length(dat))]
   day=evstr(dat(grocer_dailypart(3)))
 
   if day ~= 1 then
      month=evstr(dat(grocer_dailypart(2)))
      m=month
      while m == month
         ind_end=ind_end-1
         dat=num2date(d(ind_end),365)
         dat=[part(dat,1:indsep(1)-1);part(dat,indsep(1)+1:indsep(2)-1);...
             part(dat,indsep(2)+1:length(dat))]
         m=evstr(dat(grocer_dailypart(2)))
      end
   end
 
   s=s(ind_start:ind_end,:)
   d=d(ind_start:ind_end)
   dvec=datevec(d)
   monthvec=dvec(:,2)
   dmonthvec=monthvec(2:$)-monthvec(1:$-1)
   changmonth=[1 find(dmonthvec ~= 0)+1 ind_end-ind_start+1]
   nmonth=size(changmonth,2)-1
   news=zeros(nmonth,k)
 
   if ind == 0 then
      if dropna then
         for i=1:nmonth
          sr=s(changmonth(i):changmonth(i+1)-1,:)
          findnonna=or(~isnan(s),'c')
          news(i,:)=mean(sr(findnonna,:),1)
         end
      else
         for i=1:nmonth
            news(i,:)=mean(s(changmonth(i):changmonth(i+1)-1,:),1)
         end
      end
   else
      if dropna then
         for i=1:nmonth
            sr=s(changmonth(i):changmonth(i+1)-1,:)
            findnonna=or(~isnan(s),'c')
            news(i,:)=sum(sr(findnonna,:),1)
         end
      else
         for i=1:nmonth
            news(i,:)=sum(s(changmonth(i):changmonth(i+1)-1,:),1)
         end
      end
   end
   dat0=date2num(year+'m'+m0)
 
elseif ind >= 29 then
 
// search the last day of each month
   dvec=datevec(d)
   monthvec=dvec(:,2)
   dmonthvec=monthvec(2:$)-monthvec(1:$-1)
   changmonth=find(dmonthvec ~= 0)
   news=s(changmonth,:)
 
   if dropna then
      nanews=find(isnan(news(:,1)))
      newinds=changmonth
      indsuppr=0
      while ~isempty(nanews)
         newinds=newinds-1
         if newinds(1) < 1 then
            month=month+1
            news=news(2:$,:)
            newinds=newinds(2:$,:)
            nanews=nanews-1
            if nanews(1) < 1 then
               nanews(1)=[]
            end
         end
         news(nanews,:)=s(newinds(nanews),:)
         nanews=find(isnan(news(:,1)))
      end
   end
   dat0=date2num(year+'m'+string(month))
   nmonth=size(news,1)
 
else
   dvec=datevec(d)
   monthvec=dvec(:,2)
   dayvec=dvec(:,3)
   inddvec=find(dayvec == ind)
   news=s(inddvec,:)
   month=monthvec(inddvec(1))
   dat0=date2num(year+'m'+string(month))
   nmonth=size(news,1)
 
end
if k==1 then
  ts=tlist(['ts';'freq';'dates';'series'],[12 1],[dat0:dat0+nmonth-1]',news)
else
  ts=tlist(['tsmat';'freq';'dates';'series';'names'],[12 1],[dat0:dat0+nmonth-1]',...
          news,ts('names'))
end
endfunction
