function ts=da2q(ts,ind,dropna)
 
// PURPOSE: transforms daily data into monthly ones
// ------------------------------------------------------------
// INPUT:
// * ts = a daily timeseries
// * ind =
//   - -1 if the quarterly data is to be the sum of the
// corresponding days
//   - 0 if the  quarterly data is to be the mean of the
// corresponding days
//   - n between 1 and 90 if the quarterly data is to be the
//     value of the n-th day of the month
//   - n > 90 if the quarterly data is to be the value of the
//     last day of the quarter
// ind is optional; if not provided, it is set to -1
// * dropna = 'dropna' if the user wants to withdraw all NA
//   values from the calculations (case ind=0 or -1) or to take
//   the last non NA value of the quarter (case ind > 90)
// if not entered then all NA values are considered
// ------------------------------------------------------------
// OUTPUT:
// * ts = the corresponding quarterly time series
// ------------------------------------------------------------
// Copyright: Eric Dubois 2007
 
 
 
global GROCERDIR;
 
[nargout,nargin]=argn(0)
if nargin == 1 then
   ind=-1
end
if nargin < 3 then
   dropna=%f
elseif dropna== 'dropna' then
   dropna=%t
end
 
d=datets(ts)
s=series(ts)
k=size(s,2)
 
load(GROCERDIR+'\data\dailyform.dat')
load(GROCERDIR+'\data\basets.dat')
dat=num2date(d(1),365)
indsep=strindex(dat,grocer_dailysep)
dat=[part(dat,1:indsep(1)-1);part(dat,indsep(1)+1:indsep(2)-1);...
     part(dat,indsep(2)+1:length(dat))]
year=dat(grocer_dailypart(1))
month=evstr(dat(grocer_dailypart(2)))
day=evstr(dat(grocer_dailypart(3)))
 
if ind < 1 then
// retrieve the first day of the full quarter
// and its index in the vectors series, listna or dates
// calculate the number of full years
// and transform the listna and series in order
// to have the 4 quarterly values of one year
// on the rows of the matrix mtrans and natrans
// set div to 1 if ind=-1, to 4 if ind=0
   ind_start=1
 
   if day == 1 & modulo(month,3) == 1 then
      m0=dat(grocer_dailypart(2))
      q0=string(floor((month-1)/3)+1)
   else
      if month == 12 then
         year=string(evstr(year)+1)
         m0='01'
         q0='1'
      else
         while day ~= 1 | modulo(month,3) ~= 1 then
            ind_start=ind_start+1
            dat=num2date(d(ind_start),365)
            dat=[part(dat,1:indsep(1)-1);part(dat,indsep(1)+1:indsep(2)-1);...
               part(dat,indsep(2)+1:length(dat))]
            day=evstr(dat(grocer_dailypart(3)))
            month=evstr(dat(grocer_dailypart(2)))
         end
         m0=string(month)
         q0=string(floor((month-1)/3)+1)
      end
 
      day='01'
      newdat=emptystr(3,1)
      newdat(grocer_dailypart(1))=year
      newdat(grocer_dailypart(2))=m0
      newdat(grocer_dailypart(3))=day
      datn=newdat(1)+grocer_dailysep+newdat(2)+grocer_dailysep+newdat(3)
      ind_start=date2num(datn)-d(1)+1
   end
 
   ind_end=size(d,1)
   dat=num2date(d(ind_end)+1,365)
   dat=[part(dat,1:indsep(1)-1);part(dat,indsep(1)+1:indsep(2)-1);...
   part(dat,indsep(2)+1:length(dat))]
   day=evstr(dat(grocer_dailypart(3)))
   month=evstr(dat(grocer_dailypart(2)))
 
   while day ~= 1 | modulo(month,3) ~= 1 then
      ind_end=ind_end-1
      dat=num2date(d(ind_end),365)
      dat=[part(dat,1:indsep(1)-1);part(dat,indsep(1)+1:indsep(2)-1);...
         part(dat,indsep(2)+1:length(dat))]
      day=evstr(dat(grocer_dailypart(3)))
      month=evstr(dat(grocer_dailypart(2)))
   end
   ind_end=ind_end-1
 
   s=s(ind_start:ind_end,:)
   d=d(ind_start:ind_end,:)
   dvec=datevec(d)
   trimvec=floor((dvec(:,2)-1)/3)+1
   dtrimvec=trimvec(2:$)-trimvec(1:$-1)
   changt=[1 find(dtrimvec ~= 0)+1 ind_end-ind_start+1]
   ntrim=size(changt,2)-1
   news=zeros(ntrim,k)
 
   if ind == 0 then
      if dropna then
         for i=1:ntrim
            sr=s(changt(i):changt(i+1)-1,:)
            findnonna=or(~isnan(s),'c')
            news(i,:)=mean(sr(findnonna,:),1)
         end
      else
         for i=1:ntrim
            news(i,:)=mean(s(changt(i):changt(i+1)-1,:),1)
         end
      end
   else
      if dropna then
         for i=1:ntrim
            sr=s(changt(i):changt(i+1)-1,:)
            findnonna=or(~isnan(s),'c')
            news(i,:)=sum(sr(findnonna,:),1)
         end
      else
         for i=1:ntrim
            news(i,:)=sum(s(changt(i):changt(i+1)-1),1)
         end
      end
   end
   dat0=date2num(year+'q'+q0)
 
elseif ind >= 91 then
 
// search the last day of each month
   dvec=datevec(d)
   monthvec=dvec(:,2)
   dmonthvec=monthvec(2:$)-monthvec(1:$-1)
   changtrim=find((dmonthvec ~= 0) & (modulo(monthvec(2:$),3) == 1))
//   q0=modulo(dvec(changtrim(1)),3)
   q0=monthvec(changtrim(1))/3
   news=s(changtrim,:)
 
   if dropna then
      nanews=find(isnan(news(:,1)))
      newinds=changtrim
      indsuppr=0
      while ~isempty(nanews)
         newinds=newinds-1
         if newinds(1) < 1 then
            q0=q0+1
            news=news(2:$,:)
            newinds=newinds(2:$,:)
            nanews=nanews-1
            if nanews(1) < 1 then
               nanews(1)=[]
            end
          end
          news(nanews,:)=s(newinds(nanews),:)
          nanews=find(isnan(news(:,1)))
      end
   end
   dat0=date2num(year+'q'+string(q0))
   ntrim=size(news,1)
 
else
   dvec=datevec(d)
   monthvec=dvec(:,2)
   dmonthvec=monthvec(2:$)-monthvec(1:$-1)
   changtrim=find((dmonthvec ~= 0) & (modulo(monthvec(2:$),3) == 1))
   q0=modulo(monthvec(changtrim(1))/3,4)+1
   inds=changtrim+ind
   month_inds1=modulo(monthvec(inds(1)),3)
   day_inds1=dvec(inds(1),3)
   month_1=modulo(monthvec(1),3)
   day_1=dvec(1,3)
   news=s(inds,:)
   if month_1 <= month_inds1 & day_1 <= day_inds1 then
      // the first quarter of the data contain also the day chosen
      inds=[datenum([dvec(1,1) dvec(1,2)-(month_1-1) 1 0 0 0])-d(1)+ind inds]
      q0=q0-1+4*(q0==1)
   end
   dat0=dvec(inds(1),1)*4+q0
   ntrim=size(inds,2)
   news=s(inds,:)
end
if k==1 then
  ts=tlist(['ts';'freq';'dates';'series'],[4 1],[dat0:dat0+ntrim-1]',news)
else
  ts=tlist(['tsmat';'freq';'dates';'series';'names'],[4 1],[dat0:dat0+ntrim-1]',...
            news,ts('names'))
end
endfunction
