function ts=m2q(ts,ind)
 
// PURPOSE: transform monthly data into quarterly ones
// ------------------------------------------------------------
// INPUT:
// * ts = a monthly timeseries
// * ind =
//   - -1 if the quarterly data is to be the sum of the
// corresponding months
//   - 0 if the quarterly data is to be the mean of the
// corresponding months
//   - 1 if the quarterly data is to be the value of the
// first month
//   - 2 if the quarterly data is to be the value of the
// second month
//   - 3 if the quarterly data is to be the value of the
// third month
// ind is optional; if not provided, it is set to -1
// ------------------------------------------------------------
// OUTPUT:
// * ts = the corresponding quarterly time series
// ------------------------------------------------------------
// NOTE: if ind=0 or -1, the only full quarters are filled
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002
 
 
 
[nargout,nargin]=argn(0)
if nargin == 1 then
   ind=-1
end
 
if ind == 0 then
   div=3
else
   div=1
end
 
d=datets(ts)
s=series(ts)
k=size(s,1)
 
if ind < 1 then
// retrieve the first month of the full quarter
// and its index in the vectors series, listna or dates
// calculate the number of full quarters
// and transform the listna and series in order
// to have the 3 monthly values of one quarter
// on the rows of the matrix mtrans and natrans
   deb_m=modulo(d(1)-1,3)
   deb_ind=modulo(3-deb_m,3)+1
   nquarters=floor((size(s,1)-deb_ind+1)/3)
   if nquarters == 0 then
      disp('in m2q, not enough monthly data to build a quarter')
   end
   mtrans=matrix(s(deb_ind:deb_ind-1+3*nquarters),3,nquarters*k)'
   deb_q=(d(deb_ind)-1)/3+1
// calculate and put in an array the annual data
   ts('series')=matrix(sum(mtrans,'c')/div,nquarters,k)
else
   deb_ind=1+modulo(3-modulo(d(1)-ind,3),3)
   end_ind=size(d,1)-modulo(d(size(d,1))-ind,3)
   nquarters=(end_ind-deb_ind)/3+1
   deb_q=(d(deb_ind)-ind)/3+1
// take the series between the first and the last
// existing month of the required type and fill with 1
// to obtain a vector with a suitable length (a multiple of
// 3
   mtrans=matrix([s(deb_ind:end_ind,:);ones(2,k)],3,nquarters*k)'
   ts('series')=matrix(mtrans(:,1),nquarters,k)
end
ts('freq')=4
ts('dates')=[deb_q:deb_q+nquarters-1]'
endfunction
