function x=deal_varspec(x,name,j,boun)
 
// PURPOSE: in a matrix replace column j by the evaluation of
// a predifined expression, such as a trend, a dummy, ...
// ------------------------------------------------------------
// INPUT:
// * x = a (Txk) real matrix
// * name = a string
// * j = the affected x column
// ------------------------------------------------------------
// OUTPUT:
// * x = the transformed matrix x
// ------------------------------------------------------------
// NOTE : this function goes hand in hand with the function
// cond_varspec which defines how to recognize the variables
// whose values are implictely defined by their name instead of
// corresponding to a varaible already existing
// ------------------------------------------------------------
// Copyright: Eric Dubois 2009
// http://dubois.ensae.net/grocer.html
 
 
 
T=size(x,1)
nbounds=size(boun,1)
deldates=ones(nbounds,1)
namen=strsubst(name,' ','')
 
if namen == 'trend' then
   x(:,j)=trend(1,T)
 
elseif part(namen,1:6) == 'trend^' then
   namen=evstr(part(namen,7:length(namen)))
   x(:,j)=trend(namen,T)
 
elseif namen ~='cte' & namen ~= 'const' then
   ind_dum=strindex(namen,'dummy(')
   ind_post=strindex(namen,'post(')
   ind_rightp=strindex(namen,')')
   boundsnum=date2num_m(boun)
 
   for i=size(ind_dum,2):-1:1
      k=find(ind_rightp > ind_dum(i))
      dat=part(namen,ind_dum(i)+6:ind_rightp(k(1))-1)
      execstr('dummy_'+dat+'=zeros(T,1)')
      deldate=date2num(dat)-boundsnum
      inddate=find(deldate > 0)
 
      if isempty(inddate) then
         error('dummy('+dat+') is outside the regression bounds')
      end
 
      prevboun=inddate($)
      if floor(prevboun/2) == prevboun/2 then
         error('dummy('+dat+') is outside the regression bounds')
      end
 
      ind_dumi=deldate(prevboun)+1+sum(boundsnum(2*[1:(prevboun/2-1)])-boundsnum([1:2:2*(prevboun/2-1)-1]))
      execstr('dummy_'+dat+'('+string(ind_dumi)+')=1')
      namen=part(namen,1:ind_dum(i)+4)+'_'+dat+part(namen,ind_rightp(k(1))+1:length(namen))
   end
 
   for i=size(ind_post,2):-1:1
      k=find(ind_rightp > ind_post(i))
      dat=part(namen,ind_post(i)+5:ind_rightp(k(1))-1)
      execstr('post_'+dat+'=zeros(T,1)')
      deldate=date2num(dat)-boundsnum
      inddate=find(deldate > 0)
 
      if isempty(inddate) then
         error('post('+dat+') is outside the regression bounds')
      end
 
      prevboun=inddate($)
      if floor(prevboun/2) == prevboun/2 then
         error('post'+dat+') is outside the regression bounds')
      end
 
      ind_posti=deldate(prevboun)+1+sum(boundsnum(2*[1:(prevboun/2-1)])-boundsnum([1:2:2*(prevboun/2-1)-1]))
      execstr('post_'+dat+'('+string(ind_posti)+':$)=1')
      namen=part(namen,1:ind_post(i)+3)+'_'+dat+part(namen,ind_rightp(k(1))+1:length(namen))
   end
   x(:,j)=evstr(namen)
 
end
 
endfunction
